@@ -88,14 +88,14 @@ class evolution:
             # Since golden has been filled up, passing this testcase into resultcompare
             # won't compare anything which is exactly what we want.
             fitness = []
-            
+
             # Evaluate {self.num_samples} times and get the minimum number
             golden_run = {}
             for i in range(self.num_samples):
                 fitness.append(self._evolution.execCuprofRetrive(self))
                 if None in fitness:
                     print(self.args)
-                    raise Exception("Original binary execution error") 
+                    raise Exception("Original binary execution error")
 
                 if self.verifier['mode'] == 'file':
                     for fname in self.verifier['output']:
@@ -107,18 +107,18 @@ class evolution:
 
             for fname in self.verifier['output']:
                 variancecalc.file(golden_run[fname])
-            
+
             if self.verifier['mode'] == 'file':
                 for fname in self.verifier['output']:
                     golden_filename = f"{fname}.golden{str(self.idx)}"
                     self.golden.append(golden_filename)
-            
+
             self.fitness = (sum([ value[0] for value in fitness ])/self.num_samples, min([ value[1] for value in fitness ]))
             if None in self.fitness:
                 print(self.args)
                 raise Exception("Original binary execution error")
 
-            
+
 
     def __init__(self, kernel, bin, profile, mutop, timeout=30, fitness='time', popsize=128,
                  llvm_src_filename='cuda-device-only-kernel.ll', use_fitness_map=True, combine_positive_epistasis=False,
@@ -239,7 +239,7 @@ class evolution:
         elif self.err_rate[-1] == 's':
             err_rate = float(self.err_rate[0:-2])
         else:
-            float(self.err_rate)
+            err_rate = float(self.err_rate)
         plt.ylim(ymin=-(float(err_rate)*100/20), ymax=float(err_rate)*100)
         plt.xticks(rotation=45)
         plt.scatter([fit[0]/1000 for fit in fits], [fit[1]*100 for fit in fits],
@@ -360,7 +360,7 @@ class evolution:
                         if self.err_rate[-1] == 's':
                             rc, maxerr, avgerr = fuzzycompare.file(s, f"{g}.mean", self.err_rate, f"{g}.stddev")
                         else:
-                            rc, maxerr, avgerr = fuzzycompare.file(s, g, self.err_rate)
+                            rc, maxerr, avgerr = fuzzycompare.file(s, f"{g}.mean", self.err_rate)
                     except IndexError:
                         return False, 1
                     # if rc < 0:
@@ -399,8 +399,8 @@ class evolution:
                     tmp_edits.remove(edit)
                     ret_edits.append(edit)
                     continue
-            else: 
-                # complex edit cannot fail the test, thus won't depends on other. 
+            else:
+                # complex edit cannot fail the test, thus won't depends on other.
                 # Only other depend on them
                 tmp_edits.remove(edit)
                 ret_edits.append(edit)
@@ -530,14 +530,14 @@ class evolution:
         trial = 0
         if ind1 == ind2:
             return ind1, ind2
-        
+
         editSet1 = set(ind1.edits)
         editSet2 = set(ind2.edits)
         # The following sorting it to make the order deterministic
         intersectionEdits = sorted(list(editSet1.intersection(editSet2)))
         symmetricEdits = sorted(list(editSet1.symmetric_difference(editSet2)))
         if len(symmetricEdits) == 1:
-            return ind1, ind2 
+            return ind1, ind2
 
         while trial < len(ind1.edits) + len(ind2.edits):
             if self.teminateEvent.is_set():
@@ -726,7 +726,7 @@ class evolution:
             # search for kernel function(s)
             kernel_time = []
             time_percent = []
-            start_idx = csv_list.index(['=== [cuprof result] === '])
+            start_idx = csv_list.index(['=== [cuprof result] ==='])
             # The stats starts after 5th line
             for line in csv_list[start_idx:]:
                 if len(line) == 0:
@@ -777,7 +777,7 @@ class evolution:
         except:
             self.editFitMap[editkey] = (None, None)
             if mode is not None:
-                self.evalStats[mode]['fail'][-1] = self.evalStats[mode]['fail'][-1] + 1 
+                self.evalStats[mode]['fail'][-1] = self.evalStats[mode]['fail'][-1] + 1
             return None, None
 
         with open('gevo.ll', 'w') as f:
@@ -887,7 +887,7 @@ class evolution:
                 print(f"GEVO Error in loading rng file \"{rngFileName}\"")
                 print(sys.exc_info())
                 exit(1)
-            
+
             print(f"[resuming GEVO] Rebuilding the population from {stageFileName}. Size {popSize}")
             self.pop = self.toolbox.population(n=popSize)
             self.generation = resumeGen
