@@ -51,8 +51,14 @@ StringRef getUID(const Instruction *I) {
         StringRef UID = cast<MDString>(N->getOperand(0))->getString();
         return UID;
     }
-    else
-        return StringRef();
+    else {
+        StringRef use_name = I->getName();
+        if(!use_name.empty()) {
+            if(use_name[0] == 'U')
+                return use_name;
+        }
+        return use_name;
+    }
 }
 
 StringRef getUID(const Instruction &I) { return getUID(&I); }
@@ -68,14 +74,14 @@ void setUID(Instruction *I, std::string UID) {
 
 void setUID(Instruction *I, StringRef UID) { setUID(I, UID.str()); }
 
-Value* getConstantValue(Type* T)
+Value* getConstantValue(Type* T, int value)
 {
     switch(T->getTypeID()) {
     case Type::IntegerTyID: case Type::FixedVectorTyID:
-        return Constant::getIntegerValue(T, APInt(T->getScalarType()->getIntegerBitWidth(), 1));
+        return Constant::getIntegerValue(T, APInt(T->getScalarType()->getIntegerBitWidth(), value));
     case Type::HalfTyID:    case Type::FloatTyID:
     case Type::DoubleTyID:
-        return ConstantFP::get(T, StringRef("1"));
+        return ConstantFP::get(T, double(value));
     case Type::X86_FP80TyID:  case Type::FP128TyID:
     case Type::PPC_FP128TyID: case Type::PointerTyID:
     case Type::StructTyID:    case Type::ArrayTyID:
@@ -150,8 +156,9 @@ std::pair<Value*, StringRef> randValueBeforeI(Function *F, Instruction* boundary
 {
     std::vector<std::pair<Value*, StringRef>> resultVec;
     CollectValueBeforeI(F, boundary, refOP, resultVec);
-    // has constant to participate in drawing
-    resultVec.push_back(std::make_pair(getConstantValue(refOP->getType()), StringRef("C1")));
+    // has constant(0, 1) to participate in drawing
+    resultVec.push_back(std::make_pair(getConstantValue(refOP->getType(), 1), StringRef("C1")));
+    resultVec.push_back(std::make_pair(getConstantValue(refOP->getType(), 0), StringRef("C0")));
 
     unsigned int randIdx;
     if (is_deterministic) {
@@ -226,7 +233,7 @@ void CollectOperandAfterI(Function &F, Instruction* boundary, Type* T,
 }
 
 //Note: Type T is implicitely extracted from the boundary instruction
-std::pair<Instruction*, unsigned> randOperandAfterI(Function &F, Instruction* boundary, Type* T, bool is_deterministic) 
+std::pair<Instruction*, unsigned> randOperandAfterI(Function &F, Instruction* boundary, Type* T, bool is_deterministic)
 {
     std::vector<std::pair<Instruction*, unsigned>> OPvec;
     CollectOperandAfterI(F, boundary, T, OPvec);
@@ -320,7 +327,7 @@ bool dominates(Value* defV, Instruction *I)
 {
     if (!defV || !I)
         return false;
-    
+
     if (isa<GlobalValue>(defV) || isa<Constant>(defV))
         return true;
 
@@ -586,10 +593,12 @@ Value* walkExact(std::string inst_desc, std::string &UID, Module &M, Type* refT,
             }
         }
         else if (inst_desc[0] == 'C') {// Constant. Need to create one
+            std::string value_str(inst_desc.substr(1));
+            int value = std::stoi(value_str);
             if (refT == NULL)
                 return NULL;
             UID = inst_desc;
-            return getConstantValue(refT);
+            return getConstantValue(refT, value);
         }
         else { // For instruction
             for (Instruction &I : instructions(F)) {
@@ -622,7 +631,7 @@ int replaceOperands(StringRef dst_desc, StringRef src_desc, Module &M)
     // decompose destination description into inst and operand
     StringRef dstInstBase = (StringRef(dst_desc)).rsplit('.').first;
     StringRef dstOP = (StringRef(dst_desc)).rsplit('.').second;
-    assert(dstOP.find("OP") != StringRef::npos && "Not a valid operand description!");
+    assert(dstOP.find("OP") != StringRef::npos && "An operand description needs to include .OP!");
     unsigned OPindex = std::stoi(dstOP.drop_front(2).str());// remove "OP"
     Instruction *DI = dyn_cast_or_null<Instruction>(walkExact(dstInstBase.str(), dummy, M, NULL, false));
     if (DI == NULL)
@@ -652,8 +661,13 @@ int replaceOperands(StringRef dst_desc, StringRef src_desc, Module &M)
         if (DV == SV)
             return 1;
     }
-    else // Constant value
-        SV = getConstantValue(DV->getType());
+    else if (src_desc[0] == 'C'){// Constant value
+        std::string value_str(src_desc.substr(1));
+        int value = std::stoi(value_str);
+        SV = getConstantValue(DV->getType(), value);
+    }
+    else
+        assert("Unknown type in operand description");
 
     DI->setOperand(OPindex, SV);
     errs()<<"opreplaced "<< dst_desc << "," << src_desc << "\n";
