@@ -1,10 +1,13 @@
 #!/usr/bin/env python3
+# PYTHON_ARGCOMPLETE_OK
 import argparse
 import sys
 import subprocess
 import inspect
 import os
 
+import argcomplete
+
 # Error code
 RET_ERROR = 2
 RET_WARNING = 1
@@ -46,7 +49,7 @@ if __name__ == '__main__':
     if os.path.isfile(llvm_dis_path) is False:
         print(f'{llvm_dis_path} does not exist!')
         sys.exit(RET_ERROR)
-    
+
     # Command parser
     class MutationAction(argparse.Action):
         def __call__(self, parser, namespace, values, option_string=None):
@@ -88,9 +91,9 @@ if __name__ == '__main__':
               chain when performing mutation operations. This argument is mainly for reproducing\
               program variant from a sequence of mutations')
     llvm_mutate_parser.add_argument('--interrupt_at_fail', action='store_true')
-    llvm_mutate_parser.add_argument('-d', '--deterministic', action='store_true', 
+    llvm_mutate_parser.add_argument('-d', '--deterministic', action='store_true',
         help='make all the mutations and repairs deterministic')
-    llvm_mutate_parser.add_argument('--seed', type=int, 
+    llvm_mutate_parser.add_argument('--seed', type=int,
         help='set the random seed (only when deterministic is set to true)')
     llvm_mutate_parser.add_argument('-V', '--version', action='version', version='%(prog)s under gevo-' + __version__)
 
@@ -112,7 +115,7 @@ if __name__ == '__main__':
         '-p', '--oprepl', type=str, dest='-oprepl', action=MutationAction, metavar='INST1,INST2',
         help='replace the first Operand. with the second')
     mutation_operation_group.add_argument(
-        '-r', '--replace', type=str, dest='-replace', action=MutationAction, metavar='INST1,INST2', 
+        '-r', '--replace', type=str, dest='-replace', action=MutationAction, metavar='INST1,INST2',
         help='replace the first inst. with the second')
     mutation_operation_group.add_argument(
         '-m', '--move', type=str, dest='-move', action=MutationAction, metavar='INST1,INST2',
@@ -121,6 +124,7 @@ if __name__ == '__main__':
         '-s', '--swap', type=str, dest='-swap', action=MutationAction, metavar='INST1,INST2',
         help='swap the location of two instructions')
 
+    argcomplete.autocomplete(llvm_mutate_parser)
     args = llvm_mutate_parser.parse_args()
     ret_code = RET_SUCCESS
 
@@ -131,7 +135,7 @@ if __name__ == '__main__':
     if args.name and 'mutation_commands' in args:
         print("--name and mutation operations cannot be used together.")
         sys.exit(RET_ERROR)
-    
+
     try:
         if args.name:
             opt_proc = subprocess.Popen(
